summaryrefslogtreecommitdiff
path: root/src/pcre2_compile.c
diff options
context:
space:
mode:
authorph10 <ph10@6239d852-aaf2-0410-a92c-79f79f948069>2018-06-17 14:13:28 +0000
committerph10 <ph10@6239d852-aaf2-0410-a92c-79f79f948069>2018-06-17 14:13:28 +0000
commit1326caa549bd96e614b91db87fffee2a4de07dfc (patch)
tree8aca4b7bd292cbc509c930d29f14acdb0241091b /src/pcre2_compile.c
parenta2e7b9bd05a1b3eed13b4b94b7d32b592642cfcc (diff)
downloadpcre2-1326caa549bd96e614b91db87fffee2a4de07dfc.tar.gz
Typos in documentation and comments noted by Jason Hood.
git-svn-id: svn://vcs.exim.org/pcre2/code/trunk@936 6239d852-aaf2-0410-a92c-79f79f948069
Diffstat (limited to 'src/pcre2_compile.c')
-rw-r--r--src/pcre2_compile.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/pcre2_compile.c b/src/pcre2_compile.c
index 87530fb..5fc60f0 100644
--- a/src/pcre2_compile.c
+++ b/src/pcre2_compile.c
@@ -4261,11 +4261,11 @@ goto FAILED;
/*************************************************
* Find first significant op code *
*************************************************/
/* This is called by several functions that scan a compiled expression looking
-for a fixed first character, or an anchoring op code etc. It skips over things
+for a fixed first character, or an anchoring opcode etc. It skips over things
that do not influence this. For some calls, it makes sense to skip negative
forward and all backward assertions, and also the \b assertion; for others it
does not.
@@ -5472,7 +5472,7 @@ for (;; pptr++)
set xclass = TRUE. Then, in the pre-compile phase, accumulate the length
of the extra data and reset the pointer. This is so that very large
classes that contain a zillion wide characters or Unicode property tests
- do not overwrite the work space (which is on the stack). */
+ do not overwrite the workspace (which is on the stack). */
if (class_uchardata > class_uchardata_base)
{
@@ -7460,7 +7460,7 @@ length of the BRA and KET and any extra code units that are required at the
beginning. We accumulate in a local variable to save frequent testing of
lengthptr for NULL. We cannot do this by looking at the value of 'code' at the
start and end of each alternative, because compiled items are discarded during
-the pre-compile phase so that the work space is not exceeded. */
+the pre-compile phase so that the workspace is not exceeded. */
length = 2 + 2*LINK_SIZE + skipunits;
@@ -4261,11 +4261,11 @@ goto FAILED;
/*************************************************
-* Find first significant op code *
+* Find first significant opcode *
*************************************************/
/* This is called by several functions that scan a compiled expression looking